Crate thread_utilities

Crate thread_utilities 

Functions

get_char_column_simd
Optimized character column calculation with SIMD, finding the last newline character’s index
get_map
Returns a new RapidMap with default values.
get_set
Returns a new RapidSet with default values (a rapidhash::RapidHashSet).
hash_bytes
Computes a hash for a byte slice using rapidhash.
hash_bytes_with_seed
Computes a hash for a byte slice using rapidhash with a specified seed.
hash_file
Computes a hash for a std::fs::File object using rapidhash.
hash_file_with_seed
Computes a hash for a std::fs::File object using rapidhash with a specified seed.
is_ascii_simd
map_with_capacity
Creates a new RapidMap with the specified capacity; returning the initialized map for use.
set_with_capacity
Creates a new RapidInlineHashSet with the specified capacity; returning the initialized set for use.

Type Aliases

RapidInlineHasher
A std::hash::Hasher inspired by crate::v3::rapidhash_v3 with a focus on speed and throughput.
RapidMap
A type alias for [rapidhash::RapidHashMap].
RapidSet
A type alias for [rapidhash::RapidHashSet].