get_char_column_simd

Function get_char_column_simd 

pub fn get_char_column_simd(text: &str, offset: usize) -> usize
Optimized character column calculation with SIMD, finding the last newline character’s index

It first checks if the line is entirely ascii with is_ascii_simd, and if so, uses a faster search strategy with [find_last_byte_simd]. If there are utf-8 characters present, it still uses the same approach but then must use [count_utf8_chars_simd] to count non-continuation bytes. All operations are highly optimized with full SIMD support.